/******************************************************
 *
 * Name:         estimating-data-compression-savings.sql
 *     
 * Design Phase:
 *     Author:   John Miner
 *     Date:     03-01-2013
 *     Blog:     www.craftydba.com
 *
 *     Purpose:  How much space can I save with row
 *               versus page compression?
 *
 ******************************************************/


-- Use the correct database
USE [BIG_JONS_BBQ_DW]
GO

-- Sample call to Paul Neilson's routine (estimate)
EXEC dbo.db_compression_estimate
GO

-- What is the data/index page count?
sp_spaceused '[DIM].[DIM_DATE]'

/*
TABLE, ROWS, RESERVED, DATA, INDEX, FREE
DIM_DATE, 1095, 240 KB, 88 KB, 80 KB, 72 KB
*/


-- Try Row Compression (-27 pct)
ALTER TABLE [DIM].[DIM_DATE]
REBUILD WITH (DATA_COMPRESSION = ROW);

-- What is the data/index page count?
sp_spaceused '[DIM].[DIM_DATE]'


/*
TABLE, ROWS, RESERVED, DATA, INDEX, FREE
DIM_DATE, 1095, 152 KB, 48 KB, 80 KB, 24 KB
*/


-- Try Row Compression (-45 pct)
ALTER TABLE [DIM].[DIM_DATE]
REBUILD WITH (DATA_COMPRESSION = PAGE);

-- What is the data/index page count?
sp_spaceused '[DIM].[DIM_DATE]'


/*
TABLE, ROWS, RESERVED, DATA, INDEX, FREE
DIM_DATE 1095, 136 KB, 32 KB, 80 KB, 24 KB
*/



-- Remove the compression
ALTER TABLE [DIM].[DIM_DATE]
REBUILD WITH (DATA_COMPRESSION = NONE);

-- What is the data/index page count?
sp_spaceused '[DIM].[DIM_DATE]'